@@ -1,4 +1,6 @@
 from glob import glob
+from json import dumps as json_dumps
+from json import loads as json_loads
 from os import makedirs
 from os.path import basename
 from os.path import isdir
@@ -10,6 +12,7 @@ from sqlite3 import DatabaseError
 from sqlite3 import OperationalError
 from typing import List
 from typing import Optional
+from typing import Tuple
 
 from .__version__ import __version__
 from .database import Connection
@@ -434,7 +437,7 @@ def update_3_1_to_3_2(db: Connection) -> Connection:
         db.close()
         db_new.commit()
         db_new.close()
-        move("FA.db", "FA_3.db")
+        move("FA.db", "FA_3_1.db")
         move("FA_new.db", "FA.db")
     except (BaseException, Exception) as err:
         print("Database update interrupted!")
@@ -476,6 +479,7 @@ def update_3_2_to_3_3(db: Connection) -> Connection:
             f"""INSERT OR IGNORE INTO db_new.{settings_table}
             SELECT * FROM {settings_table} WHERE SETTING != "LASTSTART" AND SETTING != "LASTUPDATE";"""
         )
+        db.execute("UPDATE db_new.SETTINGS SET SVALUE = '3.3.0' WHERE SETTING = 'VERSION'")
 
         # Add update to history
         last_update: str = select(db, settings_table, ["SVALUE"], ["SETTING"], ["LASTUPDATE"]).fetchone()
@@ -490,7 +494,7 @@ def update_3_2_to_3_3(db: Connection) -> Connection:
         print("Close databases and replace old database")
         db_new.commit()
         db_new.close()
-        move("FA.db", "FA_3.db")
+        move("FA.db", "FA_3_2.db")
         move("FA_new.db", "FA.db")
     except (BaseException, Exception) as err:
         print("Database update interrupted!")
@@ -505,9 +509,67 @@ def update_3_2_to_3_3(db: Connection) -> Connection:
     return connect_database("FA.db")
 
 
-def update_to_current(db: Connection, version: str) -> Connection:
-    print(f"Updating {version} to {__version__}")
-    write_setting(db, "VERSION", __version__)
+def update_3_4_to_3_5(db: Connection) -> Connection:
+    print("Updating 3.4.0 to 3.5.0")
+    db_new: Optional[Connection] = None
+
+    try:
+        db_new = connect_database("FA_new.db")
+        make_tables(db_new)
+
+        # Transfer common submissions and users data
+        print("Transfer common submissions and users data")
+        db.execute("ATTACH DATABASE 'FA_new.db' AS db_new")
+        db.execute(
+            f"""INSERT OR IGNORE INTO db_new.{users_table}
+            SELECT * FROM {users_table}"""
+        )
+        db.execute(
+            f"""INSERT OR IGNORE INTO db_new.{submissions_table}
+            SELECT * FROM {submissions_table}"""
+        )
+        db.execute(
+            f"""INSERT OR IGNORE INTO db_new.{journals_table}
+            SELECT * FROM {journals_table}"""
+        )
+        db.execute(
+            f"""INSERT OR IGNORE INTO db_new.{settings_table}
+            SELECT * FROM {settings_table} WHERE SETTING != "HISTORY";"""
+        )
+        db.execute("UPDATE db_new.SETTINGS SET SVALUE = '3.5.0' WHERE SETTING = 'VERSION'")
+
+        # Update history
+        history: List[List[str]] = json_loads(
+            select(db, settings_table, ["SVALUE"], ["SETTING"], ["HISTORY"]).fetchone()[0]
+        )
+        history_new: List[Tuple[float, str]] = list(map(lambda th: (float(th[0]), th[1]), history))
+        db.commit()
+        db.close()
+        db = None
+        write_setting(db_new, "HISTORY", json_dumps(history_new))
+
+        # Close databases and replace old database
+        print("Close databases and replace old database")
+        db_new.commit()
+        db_new.close()
+        move("FA.db", "FA_3_4.db")
+        move("FA_new.db", "FA.db")
+    except (BaseException, Exception) as err:
+        print("Database update interrupted!")
+        if db is not None:
+            db.commit()
+            db.close()
+        if db_new is not None:
+            db_new.commit()
+            db_new.close()
+        raise err
+
+    return connect_database("FA.db")
+
+
+def update_version(db: Connection, version: str, target_version: str) -> Connection:
+    print(f"Updating {version} to {target_version}")
+    write_setting(db, "VERSION", target_version)
     return db
 
 
@@ -528,7 +590,11 @@ def update_database(db: Connection) -> Connection:
         return update_database(update_3_1_to_3_2(db))
     elif v >= 0 and (v := compare_versions(db_version, "3.3.0")) < 0:
         return update_database(update_3_2_to_3_3(db))
+    elif v >= 0 and (v := compare_versions(db_version, "3.4.0")) < 0:
+        return update_version(db, db_version, "3.4.0")
+    elif v >= 0 and (v := compare_versions(db_version, "3.5.0")) < 0:
+        return update_database(update_3_4_to_3_5(db))
     elif v >= 0 and compare_versions(db_version, __version__) < 0:
-        return update_to_current(db, db_version)
+        return update_version(db, db_version, __version__)
 
     return db
